@@ -9,10 +9,14 @@ from argo.workflows.client import (
 )
 from argo.workflows.client.configuration import Configuration
 from .io import Inputs, Outputs, InputParameter
+from .utils import randstr
 
 class OPTemplate:
-    def __init__(self, name, inputs=None, outputs=None, memoize_key=None, pvcs=None, annotations=None):
-        self.name = name
+    def __init__(self, name=None, inputs=None, outputs=None, memoize_key=None, pvcs=None, annotations=None):
+        if name is None:
+            name = randstr()
+        # force lowercase to fix RFC 1123
+        self.name = name.lower()
         if inputs is not None:
             self.inputs = inputs
         else:
@@ -45,32 +49,33 @@ class OPTemplate:
             self.memoize = V1alpha1Memoize(key=self.memoize_key, local_vars_configuration=config, cache=V1alpha1Cache(config_map=V1ConfigMapKeySelector(name=memoize_configmap, local_vars_configuration=config)))
 
 class ScriptOPTemplate(OPTemplate):
-    def __init__(self, name, inputs=None, outputs=None, image=None, command=None, script=None, volumes=None, mounts=None,
+    """
+    Script OP template
+
+    Args:
+        name: the name of the OP template
+        inputs: input parameters and input artifacts
+        outputs: output parameters and output artifacts
+        image: image the template uses
+        command: command to run the script
+        script: script
+        volumes: volumes the template uses
+        mounts: volumes the template mounts
+        init_progress: a str representing the initial progress
+        timeout: timeout of the OP template
+        retry_strategy: retry strategy of the OP template
+        memoize_key: memoized key of the OP template
+        pvcs: PVCs need to be declared
+        image_pull_policy: Always, IfNotPresent, Never
+        annotations: annotations for the OP template
+        cpu_requests: CPU requests
+        memory_requests: memory requests
+        cpu_limits: CPU limits
+        memory_limits: memory limits
+    """
+    def __init__(self, name=None, inputs=None, outputs=None, image=None, command=None, script=None, volumes=None, mounts=None,
             init_progress="0/1", timeout=None, retry_strategy=None, memoize_key=None, pvcs=None, resource=None,
             image_pull_policy=None, annotations=None, cpu_requests=None, memory_requests=None, cpu_limits=None, memory_limits=None):
-        """
-        Instantiate a script OP template
-        :param name: the name of the OP template
-        :param inputs: input parameters and input artifacts
-        :param outputs: output parameters and output artifacts
-        :param image: image the template uses
-        :param command: command to run the script
-        :param script: script
-        :param volumes: volumes the template uses
-        :param mounts: volumes the template mounts
-        :param init_progress: a str representing the initial progress
-        :param timeout: timeout of the OP template
-        :param retry_strategy: retry strategy of the OP template
-        :param memoize_key: memoized key of the OP template
-        :param pvcs: PVCs need to be declared
-        :param image_pull_policy: Always, IfNotPresent, Never
-        :param annotations: annotations for the OP template
-        :param cpu_requests: CPU requests
-        :param memory_requests: memory requests
-        :param cpu_limits: CPU limits
-        :param memory_limits: memory limits
-        :return:
-        """
         super().__init__(name=name, inputs=inputs, outputs=outputs, memoize_key=memoize_key, pvcs=pvcs, annotations=annotations)
         self.image = image
         self.command = command
@@ -127,32 +132,33 @@ class ScriptOPTemplate(OPTemplate):
                     command=self.command, source=self.script, volume_mounts=self.mounts, resources=V1ResourceRequirements(limits=limits, requests=requests)))
 
 class ShellOPTemplate(ScriptOPTemplate):
-    def __init__(self, name, inputs=None, outputs=None, image=None, command=None, script=None, volumes=None, mounts=None,
+    """
+    Shell script OP template
+
+    Args:
+        name: the name of the OP template
+        inputs: input parameters and input artifacts
+        outputs: output parameters and output artifacts
+        image: image the template uses
+        command: command to run the script
+        script: shell script
+        volumes: volumes the template uses
+        mounts: volumes the template mounts
+        init_progress: a str representing the initial progress
+        timeout: timeout of the OP template
+        retry_strategy: retry strategy of the OP template
+        memoize_key: memoized key of the OP template
+        pvcs: PVCs need to be declared
+        image_pull_policy: Always, IfNotPresent, Never
+        annotations: annotations for the OP template
+        cpu_requests: CPU requests
+        memory_requests: memory requests
+        cpu_limits: CPU limits
+        memory_limits: memory limits
+    """
+    def __init__(self, name=None, inputs=None, outputs=None, image=None, command=None, script=None, volumes=None, mounts=None,
             init_progress="0/1", timeout=None, retry_strategy=None, memoize_key=None, pvcs=None, image_pull_policy=None,
             annotations=None, cpu_requests=None, memory_requests=None, cpu_limits=None, memory_limits=None):
-        """
-        Instantiate a shell script OP template
-        :param name: the name of the OP template
-        :param inputs: input parameters and input artifacts
-        :param outputs: output parameters and output artifacts
-        :param image: image the template uses
-        :param command: command to run the script
-        :param script: shell script
-        :param volumes: volumes the template uses
-        :param mounts: volumes the template mounts
-        :param init_progress: a str representing the initial progress
-        :param timeout: timeout of the OP template
-        :param retry_strategy: retry strategy of the OP template
-        :param memoize_key: memoized key of the OP template
-        :param pvcs: PVCs need to be declared
-        :param image_pull_policy: Always, IfNotPresent, Never
-        :param annotations: annotations for the OP template
-        :param cpu_requests: CPU requests
-        :param memory_requests: memory requests
-        :param cpu_limits: CPU limits
-        :param memory_limits: memory limits
-        :return:
-        """
         if command is None:
             command = ["sh"]
         super().__init__(name=name, inputs=inputs, outputs=outputs, image=image, command=command, script=script, volumes=volumes,
@@ -161,32 +167,33 @@ class ShellOPTemplate(ScriptOPTemplate):
                 cpu_limits=cpu_limits, memory_limits=memory_limits)
 
 class PythonScriptOPTemplate(ScriptOPTemplate):
-    def __init__(self, name, inputs=None, outputs=None, image=None, command=None, script=None, volumes=None, mounts=None,
+    """
+    Python script OP template
+
+    Args:
+        name: the name of the OP template
+        inputs: input parameters and input artifacts
+        outputs: output parameters and output artifacts
+        image: image the template uses
+        command: command to run the script
+        script: python script
+        volumes: volumes the template uses
+        mounts: volumes the template mounts
+        init_progress: a str representing the initial progress
+        timeout: timeout of the OP template
+        retry_strategy: retry strategy of the OP template
+        memoize_key: memoized key of the OP template
+        pvcs: PVCs need to be declared
+        image_pull_policy: Always, IfNotPresent, Never
+        annotations: annotations for the OP template
+        cpu_requests: CPU requests
+        memory_requests: memory requests
+        cpu_limits: CPU limits
+        memory_limits: memory limits
+    """
+    def __init__(self, name=None, inputs=None, outputs=None, image=None, command=None, script=None, volumes=None, mounts=None,
             init_progress="0/1", timeout=None, retry_strategy=None, memoize_key=None, pvcs=None, image_pull_policy=None,
             annotations=None, cpu_requests=None, memory_requests=None, cpu_limits=None, memory_limits=None):
-        """
-        Instantiate a python script OP template
-        :param name: the name of the OP template
-        :param inputs: input parameters and input artifacts
-        :param outputs: output parameters and output artifacts
-        :param image: image the template uses
-        :param command: command to run the script
-        :param script: python script
-        :param volumes: volumes the template uses
-        :param mounts: volumes the template mounts
-        :param init_progress: a str representing the initial progress
-        :param timeout: timeout of the OP template
-        :param retry_strategy: retry strategy of the OP template
-        :param memoize_key: memoized key of the OP template
-        :param pvcs: PVCs need to be declared
-        :param image_pull_policy: Always, IfNotPresent, Never
-        :param annotations: annotations for the OP template
-        :param cpu_requests: CPU requests
-        :param memory_requests: memory requests
-        :param cpu_limits: CPU limits
-        :param memory_limits: memory limits
-        :return:
-        """
         if command is None:
             command = ["python"]
         super().__init__(name=name, inputs=inputs, outputs=outputs, image=image, command=command, script=script, volumes=volumes,
