@@ -8,40 +8,42 @@ from ..client import V1alpha1RetryStrategy
 upload_packages = []
 
 class PythonOPTemplate(PythonScriptOPTemplate):
+    """
+    Convert from Python class OP to OP template
+
+    Args:
+        op_class: Python class OP
+        image: image of the OP template
+        command: python executable
+        input_artifact_slices: a dict specifying input artifacts to use slices
+        output_artifact_save: a dict specifying storage of output artifacts overriding default storage
+        output_artifact_archive: a dict specifying compress format of output artifacts, None for no compression
+        input_parameter_slices: a dict specifying input parameters to use slices
+        output_artifact_slices: a dict specifying output artifacts to use slices
+        output_parameter_slices: a dict specifying output parameters to use slices
+        output_artifact_global_name: a dict specifying global names of output artifacts within the workflow
+        slices: use slices to generate parallel steps
+        python_packages: local python packages to be uploaded to the OP
+        timeout: timeout of the OP template
+        retry_on_transient_error: maximum retries on TrasientError
+        output_parameter_default: a dict specifying default values for output parameters
+        output_parameter_global_name: a dict specifying global names of output parameters within the workflow
+        timeout_as_transient_error: regard timeout as transient error or fatal one
+        memoize_key: memoized key of the OP template
+        volumes: volumes to use in the OP template
+        mounts: volumes to mount in the OP template
+        image_pull_policy: Always, IfNotPresent, Never
+        cpu_requests: CPU requests
+        memory_requests: memory requests
+        cpu_limits: CPU limits
+        memory_limits: memory limits
+    """
     def __init__(self, op_class, image=None, command=None, input_artifact_slices=None, output_artifact_save=None,
                  output_artifact_archive=None, input_parameter_slices=None, output_artifact_slices=None,
                  output_parameter_slices=None, output_artifact_global_name=None, slices=None, python_packages=None,
                  timeout=None, retry_on_transient_error=None, output_parameter_default=None, output_parameter_global_name=None,
                  timeout_as_transient_error=False, memoize_key=None, volumes=None, mounts=None, image_pull_policy=None,
                  cpu_requests=None, memory_requests=None, cpu_limits=None, memory_limits=None):
-        """
-        Convert from Python class OP to OP template
-        :param op_class: Python class OP
-        :param image: image of the OP template
-        :param command: python executable
-        :param input_artifact_slices: a dict specifying input artifacts to use slices
-        :param output_artifact_save: a dict specifying storage of output artifacts overriding default storage
-        :param output_artifact_archive: a dict specifying compress format of output artifacts, None for no compression
-        :param input_parameter_slices: a dict specifying input parameters to use slices
-        :param output_artifact_slices: a dict specifying output artifacts to use slices
-        :param output_parameter_slices: a dict specifying output parameters to use slices
-        :param output_artifact_global_name: a dict specifying global names of output artifacts within the workflow
-        :param slices: use slices to generate parallel steps
-        :param python_packages: local python packages to be uploaded to the OP
-        :param timeout: timeout of the OP template
-        :param retry_on_transient_error: maximum retries on TrasientError
-        :param output_parameter_default: a dict specifying default values for output parameters
-        :param output_parameter_global_name: a dict specifying global names of output parameters within the workflow
-        :param timeout_as_transient_error: regard timeout as transient error or fatal one
-        :param memoize_key: memoized key of the OP template
-        :param volumes: volumes to use in the OP template
-        :param mounts: volumes to mount in the OP template
-        :param image_pull_policy: Always, IfNotPresent, Never
-        :param cpu_requests: CPU requests
-        :param memory_requests: memory requests
-        :param cpu_limits: CPU limits
-        :param memory_limits: memory limits
-        """
         class_name = op_class.__name__
         input_sign = op_class.get_input_sign()
         output_sign = op_class.get_output_sign()
@@ -77,17 +79,17 @@ class PythonOPTemplate(PythonScriptOPTemplate):
         self.dflow_vars = {}
         for name, sign in input_sign.items():
             if isinstance(sign, Artifact):
-                self.inputs.artifacts[name] = InputArtifact(path="/tmp/inputs/artifacts/" + name, optional=sign.optional)
+                self.inputs.artifacts[name] = InputArtifact(path="/tmp/inputs/artifacts/" + name, optional=sign.optional, type=sign.type)
             elif isinstance(sign, BigParameter):
-                self.inputs.parameters[name] = InputParameter(save_as_artifact=True, path="/tmp/inputs/parameters/" + name)
+                self.inputs.parameters[name] = InputParameter(save_as_artifact=True, path="/tmp/inputs/parameters/" + name, type=sign.type)
             else:
-                self.inputs.parameters[name] = InputParameter()
+                self.inputs.parameters[name] = InputParameter(type=sign)
         for name, sign in output_sign.items():
             if isinstance(sign, Artifact):
                 self.outputs.artifacts[name] = OutputArtifact(path="/tmp/outputs/artifacts/" + name,
-                    archive=sign.archive, save=sign.save, global_name=sign.global_name)
+                    archive=sign.archive, save=sign.save, global_name=sign.global_name, type=sign.type)
             elif isinstance(sign, BigParameter):
-                self.outputs.parameters[name] = OutputParameter(save_as_artifact=True, value_from_path="/tmp/outputs/parameters/" + name)
+                self.outputs.parameters[name] = OutputParameter(save_as_artifact=True, value_from_path="/tmp/outputs/parameters/" + name, type=sign.type)
             else:
                 default = None
                 if output_parameter_default is not None and name in output_parameter_default:
@@ -98,7 +100,7 @@ class PythonOPTemplate(PythonScriptOPTemplate):
                 global_name = None
                 if output_parameter_global_name is not None and name in output_parameter_global_name:
                     global_name = output_parameter_global_name[name]
-                self.outputs.parameters[name] = OutputParameter(value_from_path="/tmp/outputs/parameters/" + name, default=default, global_name=global_name)
+                self.outputs.parameters[name] = OutputParameter(value_from_path="/tmp/outputs/parameters/" + name, default=default, global_name=global_name, type=sign)
 
         if python_packages is None:
             python_packages = upload_packages
@@ -197,15 +199,17 @@ class PythonOPTemplate(PythonScriptOPTemplate):
         return slices
 
 class Slices:
+    """
+    Slices specified in PythonOPTemplate
+
+    Args:
+        slices: slice pattern
+        input_parameter: list of input parameters to be sliced
+        input_artifact: list of input artifacts to be sliced
+        output_parameter: list of output parameters to be stacked
+        output_artifact: list of output artifacts to be stacked
+    """
     def __init__(self, slices=None, input_parameter=None, input_artifact=None, output_parameter=None, output_artifact=None):
-        """
-        Instantiate a slices specified in PythonOPTemplate
-        :param slices: slice pattern
-        :param input_parameter: list of input parameters to be sliced
-        :param input_artifact: list of input artifacts to be sliced
-        :param output_parameter: list of output parameters to be stacked
-        :param output_artifact: list of output artifacts to be stacked
-        """
         self.slices = slices
         self.input_parameter = input_parameter
         self.input_artifact = input_artifact
